@@ -87,6 +87,7 @@ class Flake8Item(pytest.Item, pytest.File):
     def __init__(self, path, parent, flake8ignore, maxlength,
                  maxcomplexity, showshource, statistics):
         super(Flake8Item, self).__init__(path, parent)
+        self._nodeid += "::FLAKE8"
         self.add_marker("flake8")
         self.flake8ignore = flake8ignore
         self.maxlength = maxlength
@@ -183,7 +184,8 @@ def check_file(path, flake8ignore, maxlength, maxcomplexity,
     app.find_plugins()
     app.register_plugin_options()
     app.parse_configuration_and_cli(args)
-    app.options.ignore.extend(flake8ignore)
+    if flake8ignore:
+        app.options.ignore = flake8ignore
     app.make_formatter()  # fix this
     app.make_notifier()
     app.make_guide()
